@@ -1,7 +1,7 @@
 /*
 *   C++ Implementation: daisy
 *   Description: a daisy for plasma
-*   Copyright (C) 2009 by Lechio <Alessandros1pt@yahoo.com.br>
+*   Copyright (C) 2009,2010 by Lechio <Alessandros1pt@yahoo.com.br>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
@@ -273,6 +273,7 @@ void daisy::init()
   getAllTasks();
   m_paint_tmr->start();
   raise();
+  setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding));
   
 }
 
@@ -568,6 +569,8 @@ void daisy::constraintsEvent(Plasma::Constraints constraints)
   if (constraints & Plasma::SizeConstraint)
   {}
   
+  
+  
 }
 
 
@@ -870,7 +873,7 @@ void daisy::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 	  if (m_task)
 	  {
 	    TaskManager::BasicMenu *taskMenu;TaskManager::TaskItem *taskitem;
-	    taskitem = new TaskManager::TaskItem::TaskItem(this, m_task);
+	    taskitem = new TaskManager::TaskItem(this, m_task);
 	    taskMenu = new TaskManager::BasicMenu( qobject_cast<QWidget*>(this), taskitem, m_groupManager );
 	    taskMenu->popup( event->screenPos() );
 	  }
@@ -896,7 +899,7 @@ void daisy::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 	  {
 	    QList<QAction*> actionList;actionList << m_act_newinstance << m_act_editlauncher;
 	    TaskManager::BasicMenu *taskMenu;TaskManager::TaskItem *taskitem;
-	    taskitem = new TaskManager::TaskItem::TaskItem(this, m_task);
+	    taskitem = new TaskManager::TaskItem(this, m_task);
 	    taskMenu = new TaskManager::BasicMenu( qobject_cast<QWidget*>(this), taskitem, m_groupManager, actionList );
 	    taskMenu->popup( event->screenPos() );
 	  }
@@ -1194,7 +1197,7 @@ void daisy::resizeRepos( bool m_resetpos )
       setMinimumSize(330,330);
       setMaximumSize(330,330);
       resize(330,330);
-      setPos(QPointF(62,268));
+      if (!m_inpanel)setPos(QPointF(62,268));
       QTimer::singleShot(150, this, SLOT(resetResize()));
     }
     if (!m_inpanel)setMinimumSize(100,100);
@@ -1499,9 +1502,6 @@ void daisy::setTheme()
   
   
   
-  else if ( m_theme_t == QString("cavalino-red") )
-  {m_backframe_t.setImagePath("widgets/dock-background-cavalino-red");}
-  
   else if ( m_theme_t == QString("mach") )
   {m_backframe_t.setImagePath("widgets/dock-background-mach");}
   
@@ -1514,18 +1514,6 @@ void daisy::setTheme()
   else if ( m_theme_t == QString("vidro") )
   {m_backframe_t.setImagePath("widgets/dock-background-vidro");}
   
-  else if ( m_theme_t == QString("blueish") )
-  {m_backframe_t.setImagePath("widgets/dock-background-blueish");}
-  
-  else if ( m_theme_t == QString("reddish") )
-  {m_backframe_t.setImagePath("widgets/dock-background-reddish");}
-  
-  else if ( m_theme_t == QString("rubber-black") )
-  {m_backframe_t.setImagePath("widgets/dock-background-rubber-black");}
-  
-  else if ( m_theme_t == QString("kiwi") )
-  {m_backframe_t.setImagePath("widgets/dock-background-kiwi");}
-  
   
   else
   {m_backframe_t.setImagePath("widgets/translucentbackground");}
@@ -1828,7 +1816,7 @@ void daisy::delayUpdate(void)
 void daisy::resetResize(void)
 {
   resize(330,330);
-  setPos(QPointF(62,268));
+  if (!m_inpanel)setPos(QPointF(62,268));
   setMaximumSize(2330,2330);
 }
 
