@@ -1,7 +1,7 @@
 /*
 *   Configuration: daisy
 *   Description: a daisy for plasma
-*   Copyright (C) 2009 by Lechio <Alessandros1pt@yahoo.com.br>
+*   Copyright (C) 2009,2010 by Lechio <Alessandros1pt@yahoo.com.br>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
@@ -390,7 +390,7 @@ void daisy::readConfiguration()
   m_zoomtype = cg.readEntry("zoomtype", QString("framed"));
   m_click_effects = cg.readEntry("click_effects", false);
   m_click_effect_type = cg.readEntry("click_effect_type", QString("default"));
-  m_tiptype = cg.readEntry("tip_type", QString("icon"));
+  m_tiptype = cg.readEntry("tip_type", QString("thumbnail"));
   m_drawersize = cg.readEntry("drawersize", 38);
   m_drawerrotation = cg.readEntry("drawerrotation", 1.50);
   m_showtaskoflauncher = cg.readEntry("showtaskoflauncher", true);
