@@ -1,7 +1,7 @@
 /*
 *   Configuration: daisy
 *   Description: a daisy for plasma
-*   Copyright (C) 2009 by Lechio <Alessandros1pt@yahoo.com.br>
+*   Copyright (C) 2009,2010 by Lechio <Alessandros1pt@yahoo.com.br>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
@@ -297,30 +297,20 @@ void daisy::insertBacks()
   m_appearanceConfigurationUi.comboBoxBackground->addItem( i18n("translucent") );
   m_appearanceConfigurationUi.comboBoxBackground->addItem( i18n("opaque") );
   m_appearanceConfigurationUi.comboBoxBackground->addItem( i18n("alternative") );
-  m_appearanceConfigurationUi.comboBoxBackground->addItem( i18n("cavalino-red") );
   m_appearanceConfigurationUi.comboBoxBackground->addItem( i18n("mach") );
   m_appearanceConfigurationUi.comboBoxBackground->addItem( i18n("mach-2") );
   m_appearanceConfigurationUi.comboBoxBackground->addItem( i18n("shiny-black") );
   m_appearanceConfigurationUi.comboBoxBackground->addItem( i18n("vidro") );
-  m_appearanceConfigurationUi.comboBoxBackground->addItem( i18n("blueish") );
-  m_appearanceConfigurationUi.comboBoxBackground->addItem( i18n("reddish") );
-  m_appearanceConfigurationUi.comboBoxBackground->addItem( i18n("rubber-black") );
-  m_appearanceConfigurationUi.comboBoxBackground->addItem( i18n("kiwi") );
   
   
   if ( m_theme_t == QString("translucent") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(1);
   else if ( m_theme_t == QString("opaque") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(2);
   else if ( m_theme_t == QString("alternative") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(3);
   
-  else if ( m_theme_t == QString("cavalino-red") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(4);
-  else if ( m_theme_t == QString("mach") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(5);
-  else if ( m_theme_t == QString("mach-2") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(6);
-  else if ( m_theme_t == QString("shiny-black") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(7);
-  else if ( m_theme_t == QString("vidro") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(8);
-  else if ( m_theme_t == QString("blueish") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(9);
-  else if ( m_theme_t == QString("reddish") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(10);
-  else if ( m_theme_t == QString("rubber-black") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(11);
-  else if ( m_theme_t == QString("kiwi") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(12);
+  else if ( m_theme_t == QString("mach") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(4);
+  else if ( m_theme_t == QString("mach-2") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(5);
+  else if ( m_theme_t == QString("shiny-black") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(6);
+  else if ( m_theme_t == QString("vidro") ) m_appearanceConfigurationUi.comboBoxBackground->setCurrentIndex(7);
   
 }
 
@@ -397,15 +387,10 @@ void daisy::configAccepted()
     else if (m_box_index == 1)m_theme_t = QString("translucent");
     else if (m_box_index == 2)m_theme_t = QString("opaque");
     else if (m_box_index == 3)m_theme_t = QString("alternative");
-    else if (m_box_index == 4)m_theme_t = QString("cavalino-red");
-    else if (m_box_index == 5)m_theme_t = QString("mach");
-    else if (m_box_index == 6)m_theme_t = QString("mach-2");
-    else if (m_box_index == 7)m_theme_t = QString("shiny-black");
-    else if (m_box_index == 8)m_theme_t = QString("vidro");
-    else if (m_box_index == 9)m_theme_t = QString("blueish");
-    else if (m_box_index == 10)m_theme_t = QString("reddish");
-    else if (m_box_index == 11)m_theme_t = QString("rubber-black");
-    else if (m_box_index == 12)m_theme_t = QString("kiwi");
+    else if (m_box_index == 4)m_theme_t = QString("mach");
+    else if (m_box_index == 5)m_theme_t = QString("mach-2");
+    else if (m_box_index == 6)m_theme_t = QString("shiny-black");
+    else if (m_box_index == 7)m_theme_t = QString("vidro");
   }
   // Role
   m_box_index = m_mainConfigurationUi.comboBox_role->currentIndex();
@@ -759,15 +744,10 @@ void daisy::backgroundChanged( int value )
     else if (value == 2)m_theme_t = QString("opaque");
     else if (value == 3)m_theme_t = QString("alternative");
     
-    else if (value == 4)m_theme_t = QString("cavalino-red");
-    else if (value == 5)m_theme_t = QString("mach");
-    else if (value == 6)m_theme_t = QString("mach-2");
-    else if (value == 7)m_theme_t = QString("shiny-black");
-    else if (value == 8)m_theme_t = QString("vidro");
-    else if (value == 9)m_theme_t = QString("blueish");
-    else if (value == 10)m_theme_t = QString("reddish");
-    else if (value == 11)m_theme_t = QString("rubber-black");
-    else if (value == 12)m_theme_t = QString("kiwi");
+    else if (value == 4)m_theme_t = QString("mach");
+    else if (value == 5)m_theme_t = QString("mach-2");
+    else if (value == 6)m_theme_t = QString("shiny-black");
+    else if (value == 7)m_theme_t = QString("vidro");
     
     setTheme();
     emit update();
@@ -971,7 +951,7 @@ void daisy::configLauncherAccepted(void)
   m_widgets[m_launtoedit] = new MyIcon( m_values[m_launtoedit], m_avalues[m_launtoedit], m_acta[m_launtoedit], this );
   m_act_1 = new QAction(KIcon(icoret_tmp), "", this);
   m_widgets[m_launtoedit]->setAction(m_act_1);
-  connect(m_widgets[m_launtoedit], SIGNAL(clicked()), this, SLOT(launClick()));
+  connect(m_widgets[m_launtoedit], SIGNAL(pressed(bool)), this, SLOT(launClick()));
   polishLaunchers();
   m_widgets[m_launtoedit]->installEventFilter(this);
   
